---
layout: default
---

[![Build Status](https://travis-ci.org/biolink/biolinkml.svg?branch=master)](https://travis-ci.org/biolink/biolinkml)

# biolinkml - Biolink Modeling Language

A YAML based modeling tool for the biolink project.  Models are expressed in the YAML based biolinkml modeling language
and can be converted into:
* Python 3 classes
* [GOlr](http://wiki.geneontology.org/index.php/GOlr) - Solr index for the Gene Ontology
* Class and interface definitions for [GraphQL](https://graphql.org/)
* Graphviz -- fairly basic representation of hierarchies
* [JSON](https://json.org/) and [JSON-LD](https://json-ld.org/)
* [JSON Schema](https://json-schema.org/)
* [Markdown](https://daringfireball.net/projects/markdown/) - markup language used by github and others
* [OWL](https://www.w3.org/TR/2012/REC-owl2-overview-20121211/) - Web Ontology Language
* [RDF](https://www.w3.org/2001/sw/wiki/RDF) - Resource Description Format
* [ShEx](http://shex.io/shex-semantics/index.html) - Shape Expressions Langauge
* [YUML](https://yuml.me/) - UML diagram drawing tool


## Modeling Language URI's
